@@ -3,6 +3,7 @@ import sys
 import argparse
 from glob import glob
 from ..client.main import IcatClient
+from ..client import defaults
 
 
 def main(argv=None):
@@ -28,7 +29,7 @@ def add_store_parameters(parser):
         "--queue",
         dest="metadata_urls",
         action="append",
-        help="ActiveMQ queue URLS. Example: bcu-mq-01.esrf.fr:61613",
+        help="ActiveMQ queue URLS",
         default=[],
     )
 
@@ -37,7 +38,7 @@ def apply_store_parameters(args):
     args.files = sorted(glob(args.filter), key=os.path.getmtime)
 
     if not args.metadata_urls:
-        args.metadata_urls = ["bcu-mq-01.esrf.fr:61613", "bcu-mq-02.esrf.fr:61613"]
+        args.metadata_urls = defaults.METADATA_BROKERS
 
 
 if __name__ == "__main__":
