@@ -1,8 +1,9 @@
 import json
 from enum import Enum
-from typing import Optional
+from typing import Optional, List
 
 from .messaging import IcatMessagingClient
+from . import defaults
 
 
 class StatusType(Enum):
@@ -21,11 +22,15 @@ class IcatArchiveStatusClient:
 
     def __init__(
         self,
-        queue_urls: list,
-        queue_name: str = "icatArchiveRestoreStatus",
+        queue_urls: Optional[List[str]] = None,
+        queue_name: Optional[str] = None,
         monitor_port: Optional[int] = None,
         timeout: Optional[float] = None,
     ):
+        if queue_name is None:
+            queue_name = defaults.ARCHIVE_QUEUE
+        if queue_urls is None:
+            queue_urls = defaults.ARCHIVE_BROKERS
         self._client = IcatMessagingClient(
             queue_urls, queue_name, monitor_port=monitor_port, timeout=timeout
         )
