@@ -14,10 +14,10 @@ class IcatClient(IcatClientInterface):
 
     def __init__(
         self,
-        metadata_urls: Optional[list] = None,
+        metadata_urls: Optional[List[str]] = None,
         elogbook_url: Optional[str] = None,
-        elogbook_token: Optional[str] = "elogbook-00000000-0000-0000-0000-000000000000",
-        metadata_queue: Optional[str] = "icatIngest",
+        elogbook_token: Optional[str] = None,
+        metadata_queue: Optional[str] = None,
         metadata_queue_monitor_port: Optional[int] = None,
         elogbook_timeout: Optional[float] = None,
         feedback_timeout: Optional[float] = None,
@@ -25,8 +25,8 @@ class IcatClient(IcatClientInterface):
         beamline: Optional[str] = None,
         proposal: Optional[str] = None,
         elogbook_metadata: Optional[Mapping] = None,
-        archive_urls: Optional[list] = None,
-        archive_queue: Optional[str] = "icatArchiveRestoreStatus",
+        archive_urls: Optional[List[str]] = None,
+        archive_queue: Optional[str] = None,
         archive_queue_monitor_port: Optional[int] = None,
     ):
         self.current_proposal = proposal
@@ -56,11 +56,13 @@ class IcatClient(IcatClientInterface):
             self._investigation_client = IcatInvestigationClient(
                 url=elogbook_url, api_key=elogbook_token, timeout=feedback_timeout
             )
+            if elogbook_metadata is None:
+                elogbook_metadata = dict()
             self._elogbook_client = IcatElogbookClient(
                 url=elogbook_url,
                 api_key=elogbook_token,
                 timeout=elogbook_timeout,
-                payload=elogbook_metadata,
+                **elogbook_metadata,
             )
         else:
             self._investigation_client = None
@@ -292,7 +294,9 @@ class IcatClient(IcatClientInterface):
             if metadata is None:
                 metadata = dict()
         if raw:
-            if isinstance(raw, Sequence):
+            if isinstance(raw, str):
+                metadata["input_datasets"] = [raw]
+            elif isinstance(raw, Sequence):
                 metadata["input_datasets"] = list(raw)
             else:
                 metadata["input_datasets"] = [raw]
